Contributors — FireWorks 1.4.4 documentation

# Contributors

FireWorks was developed primarily by Anubhav Jain at Lawrence Berkeley National Lab, using research funding from Kristin Persson for the Materials Project.

Additional contributions from: - Shyue Ping Ong - Xiaohui Qu - Wei Chen - Bharat Medasani - Michael Kocher - Dan Gunter - Guido Petretto - Morgan Hargrove - Miriam Brafman - David Waroquiers - Chris Harris - William Davidson Richards - Felix Brockherde - Zach Ulissi - William Scullin - Shyam Dwaraknath - Brian Foster - Ganesh Panchapakesan - Patrick Huck - Donny Winston - Joey Montoya - Henrik Rusche - David Cossey - David Dodson - Kiran Mathew - Murat Aykol - Felix Zapata - Dale Stansberry - Ketan Bhatt - Richard Gowers - Github user: kpoman - Github user: jakirkham - Github user: shenjh - Github user: specter119 - Github user: KeLiu

Thanks for helpful discussions: - Marat Valiev - Stephen Bailey - Deborah Bard

We thank JetBrains for providing PyCharm IDE licenses for FireWorks developers.